[![CI](https://github.com/childmindresearch/skarf/actions/workflows/ci.yaml/badge.svg?branch=main)](https://github.com/childmindresearch/skarf/actions/workflows/ci.yaml?query=branch%3Amain)
[![Documentation](https://img.shields.io/badge/documentation-8CA1AF?logo=readthedocs&logoColor=fff)](https://childmindresearch.github.io/skarf)
[![codecov](https://codecov.io/gh/childmindresearch/skarf/branch/main/graph/badge.svg?token=22HWWFWPW5)](https://codecov.io/gh/childmindresearch/skarf)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![Python3](https://img.shields.io/badge/python->=3.11-blue.svg)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE)

<p align="left">
  <img src="doc/_static/img/skarf_logo.svg" height="200">
</p>

skarf (**s**ci**k**it **a**uto**r**egressive models for **f**unctional connectivity) is a Python package for regularized vector autoregressive (VAR) time series modeling built on top of [scikit-learn](https://scikit-learn.org). It is built for functional connectivity analyses of fMRI data.

## Installation

You can install the latest release from PyPI with

```bash
pip install skarf
```

The latest development version can be installed with

```bash
pip install git+https://github.com/childmindresearch/skarf.git
```

## Documentation

Package documentation is available [here](https://childmindresearch.github.io/skarf).
